==> hgug4100a_1.8.4.tar.gz: hgug4100a/man/hgug4100aOMIM.Rd <==
\name{hgug4100aOMIM}
\alias{hgug4100aOMIM}
\title{Map between Manufacturer Identifiers and Mendelian Inheritance in
  Man (MIM) identifiers}
\description{
  hgug4100aOMIM is an R environment that provides mappings between
  manufacturer ids and OMIM ids.
}
\details{
  Each manufacturer id is mapped to a vector of OMIM ids. The vector
  length may be one or longer, depending on how many OMIM ids the
  manufacturer id maps to. An \code{NA} is reported for any manufacturer
  id that cannot be mapped to an OMIM id at this time.
  
  OMIM is based upon the book Mendelian Inheritance in Man
  (V. A. McKusick) and focuses primarily on inherited or heritable
  genetic diseases. It contains textual information, pictures, and reference
  information that can be searched using various terms, among which the
  MIM number is one. 
  
  Mappings were based on data provided by:

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue May 17 13:56:27 2005

  Package built Tue May 17 14:03:38 2005
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
  \url{http://www3.ncbi.nlm.nih.gov/entrez/query.fcgi?db=OMIM}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hgug4100aOMIM)
    # Remove probe ids that do not map to any MIM number
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The MIM numbers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    }
}

\keyword{datasets}

==> hgug4100a_1.10.0.tar.gz: hgug4100a/man/hgug4100aOMIM.Rd <==
\name{hgug4100aOMIM}
\alias{hgug4100aOMIM}
\title{Map between Manufacturer Identifiers and Mendelian Inheritance in
  Man (MIM) identifiers}
\description{
  hgug4100aOMIM is an R environment that provides mappings between
  manufacturer ids and OMIM ids.
}
\details{
  Each manufacturer id is mapped to a vector of OMIM ids. The vector
  length may be one or longer, depending on how many OMIM ids the
  manufacturer id maps to. An \code{NA} is reported for any manufacturer
  id that cannot be mapped to an OMIM id at this time.
  
  OMIM is based upon the book Mendelian Inheritance in Man
  (V. A. McKusick) and focuses primarily on inherited or heritable
  genetic diseases. It contains textual information, pictures, and reference
  information that can be searched using various terms, among which the
  MIM number is one. 
  
  Mappings were based on data provided by:

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 20:19:42 2005

  Package built Tue Oct  4 20:35:05 2005
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene}
  \url{http://www3.ncbi.nlm.nih.gov/entrez/query.fcgi?db=OMIM}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(hgug4100aOMIM)
    # Remove probe ids that do not map to any MIM number
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # The MIM numbers for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
    }
}

\keyword{datasets}
